Module function

Module function 

This module implements the global Function object as well as creates Native Functions.

Objects wrap Functions and expose them via call/construct slots.

The Function` object is used for matching text with a pattern.

More information:

Structs

BuiltInFunction
BuiltInFunctionObject
Captures
Wrapper for Box<dyn NativeObject + Clone> that allows passing additional captures through a Copy closure.
FunctionFlags

Enums

Function
Boa representation of a Function Object.

Traits

ClosureFunction
Trait representing a native built-in closure.
DynCopy

Functions

create_unmapped_arguments_object
Arguments.
make_builtin_fn
Creates a new member function of a Object or prototype.

Type Aliases

NativeFunction
Type representing a native built-in function a.k.a. function pointer.