Struct boa::builtins::function::Captures[][src]

pub struct Captures(_);
Wrapper for Box<dyn NativeObject + Clone> that allows passing additional captures through a Copy closure.

Any type implementing Trace + Any + Debug + Clone can be used as a capture context, so you can pass e.g. a String, a tuple or even a full struct.

You can downcast to any type and handle the fail case as you like with downcast_ref and downcast_mut, or you can use try_downcast_ref and try_downcast_mut to automatically throw a TypeError if the downcast fails.

Implementations

Downcasts Captures to the specified type, returning a reference to the downcasted type if successful or None otherwise.

Mutably downcasts Captures to the specified type, returning a mutable reference to the downcasted type if successful or None otherwise.

Downcasts Captures to the specified type, returning a reference to the downcasted type if successful or a TypeError otherwise.

Downcasts Captures to the specified type, returning a reference to the downcasted type if successful or a TypeError otherwise.