Struct boa::builtins::set::ordered_set::OrderedSet [−][src]
pub struct OrderedSet<V, S = RandomState>(_)
where
V: Hash + Eq;Expand description
A newtype wrapping indexmap::IndexSet
Implementations
Return the number of key-value pairs in the map.
Computes in O(1) time.
Returns true if the map contains no elements.
Computes in O(1) time.
Insert a value pair in the set.
If an equivalent value already exists in the set: ???
If no equivalent value existed in the set: the new value is inserted, last in order, and false
Computes in O(1) time (amortized average).
Delete the value from the set and return true if successful
Return false if value is not in map.
Computes in O(n) time (average).
Checks if a given value is present in the set
Return true if value is present in set, false otherwise.
Computes in O(n) time (average).
Get a key-value pair by index Valid indices are 0 <= index < self.len() Computes in O(1) time.