Struct boa::class::ClassBuilder[][src]

pub struct ClassBuilder<'context> { /* fields omitted */ }
Class builder which allows adding methods and static methods to the class.

Implementations

Add a method to the class.

It is added to prototype.

Add a static method to the class.

It is added to class object itself.

Add a data property to the class, with the specified attribute.

It is added to prototype.

Add a static data property to the class, with the specified attribute.

It is added to class object itself.

Add an accessor property to the class, with the specified attribute.

It is added to prototype.

Add a static accessor property to the class, with the specified attribute.

It is added to class object itself.

Add a property descriptor to the class, with the specified attribute.

It is added to prototype.

Add a static property descriptor to the class, with the specified attribute.

It is added to class object itself.

Return the current context.