Struct boa::environment::declarative_environment_record::DeclarativeEnvironmentRecord[][src]

pub struct DeclarativeEnvironmentRecord {
    pub env_rec: GcCell<FxHashMap<Box<str>, DeclarativeEnvironmentRecordBinding>>,
    pub outer_env: Option<Environment>,
}
A declarative Environment Record binds the set of identifiers defined by the declarations contained within its scope.

Fields

env_rec: GcCell<FxHashMap<Box<str>, DeclarativeEnvironmentRecordBinding>>outer_env: Option<Environment>

Implementations