Struct boa::environment::declarative_environment_record::DeclarativeEnvironmentRecordBinding [−][src]
pub struct DeclarativeEnvironmentRecordBinding {
pub value: Option<JsValue>,
pub can_delete: bool,
pub mutable: bool,
pub strict: bool,
}Expand description
Declarative Bindings have a few properties for book keeping purposes, such as mutability (const vs let). Can it be deleted? and strict mode.
So we need to create a struct to hold these values. From this point onwards, a binding is referring to one of these structures.
Fields
value: Option<JsValue>can_delete: boolmutable: boolstrict: boolTrait Implementations
Runs Finalize::finalize() on this object and all contained subobjects Read more