Enum boa::environment::function_environment_record::BindingStatus[][src]

pub enum BindingStatus {
    Lexical,
    Initialized,
    Uninitialized,
}
Different binding status for this. Usually set on a function environment record

Variants

Lexical

If the value is “lexical”, this is an ArrowFunction and does not have a local this value.

Initialized

If initialized the function environment record has already been bound with a this value

Uninitialized

If uninitialized the function environment record has not been bouned with a this value