Enum boa::environment::lexical_environment::VariableScope [−][src]
pub enum VariableScope {
Block,
Function,
}Expand description
The scope of a given variable
Variants
The variable declaration is scoped to the current block (let and const)
The variable declaration is scoped to the current function (var)