[−][src]Module boa::js::function
The global Function object and function value representations
Structs
| NativeFunction | Represents a native javascript function in memory |
| RegularFunction | Represents a regular javascript function in memory |
Enums
| Function | A Javascript function A member of the Object type that may be invoked as a subroutine https://tc39.github.io/ecma262/#sec-terms-and-definitions-function In our implementation, Function is extending Object by holding an object field which some extra data A Javascript function |
Functions
| _create | Create a new |
| init | Initialise the global object with the |
Type Definitions
| NativeFunctionData | fn(this, callee, arguments) |