[−][src]Enum boa::js::function::Function
A Javascript function A member of the Object type that may be invoked as a subroutine https://tc39.github.io/ecma262/#sec-terms-and-definitions-function In our implementation, Function is extending Object by holding an object field which some extra data A Javascript function
Variants
NativeFunc(NativeFunction)A native javascript function
RegularFunc(RegularFunction)A regular javascript function