[−][src]Struct boa::js::object::Property
A Javascript Property AKA The Property Descriptor
[SPEC] - The Property Descriptor Specification Type
[SPEC] - Default Attribute Values
Fields
configurable: boolIf the type of this can be changed and this can be deleted
enumerable: boolIf the property shows up in enumeration of the object
writable: boolIf this property can be changed with an assignment
value: ValueThe value associated with the property
get: ValueThe function serving as getter
set: ValueThe function serving as setter
Methods
impl Property[src]