Enum boa::object::IntegrityLevel[][src]

pub enum IntegrityLevel {
    Sealed,
    Frozen,
}
Object integrity level.

Variants

Sealed

Sealed object integrity level.

Preventing new properties from being added to it and marking all existing properties as non-configurable. Values of present properties can still be changed as long as they are writable.

Frozen

Frozen object integrity level

A frozen object can no longer be changed; freezing an object prevents new properties from being added to it, existing properties from being removed, prevents changing the enumerability, configurability, or writability of existing properties, and prevents the values of existing properties from being changed. In addition, freezing an object also prevents its prototype from being changed.

Implementations

Returns true if the integrity level is sealed.

Returns true if the integrity level is frozen.