Struct boa::object::FunctionBuilder [−][src]
pub struct FunctionBuilder<'context> { /* fields omitted */ }Expand description
Builder for creating native function objects
Implementations
Create a new FunctionBuilder for creating a native function.
Create a new FunctionBuilder for creating a closure function.
Create a new closure function with additional captures.
Note
You can only move variables that implement Debug + Any + Trace + Clone.
In other words, only NativeObject + Clone objects are movable.
Specify the name property of object function object.
The default is "" (empty string).
Specify the length property of object function object.
How many arguments this function takes.
The default is 0.
Specify the whether the object function object can be called with new keyword.
The default is false.