Struct boa::object::PropertyMap[][src]

pub struct PropertyMap { /* fields omitted */ }

Implementations

An iterator visiting all key-value pairs in arbitrary order. The iterator element type is (PropertyKey, &'a Property).

This iterator does not recurse down the prototype chain.

An iterator visiting all keys in arbitrary order. The iterator element type is PropertyKey.

This iterator does not recurse down the prototype chain.

An iterator visiting all values in arbitrary order. The iterator element type is &'a Property.

This iterator does not recurse down the prototype chain.

An iterator visiting all symbol key-value pairs in arbitrary order. The iterator element type is (&'a RcSymbol, &'a Property).

This iterator does not recurse down the prototype chain.

An iterator visiting all symbol keys in arbitrary order. The iterator element type is &'a RcSymbol.

This iterator does not recurse down the prototype chain.

An iterator visiting all symbol values in arbitrary order. The iterator element type is &'a Property.

This iterator does not recurse down the prototype chain.

An iterator visiting all indexed key-value pairs in arbitrary order. The iterator element type is (&'a u32, &'a Property).

This iterator does not recurse down the prototype chain.

An iterator visiting all index keys in arbitrary order. The iterator element type is &'a u32.

This iterator does not recurse down the prototype chain.

An iterator visiting all index values in arbitrary order. The iterator element type is &'a Property.

This iterator does not recurse down the prototype chain.

An iterator visiting all string key-value pairs in arbitrary order. The iterator element type is (&'a RcString, &'a Property).

This iterator does not recurse down the prototype chain.

An iterator visiting all string keys in arbitrary order. The iterator element type is &'a RcString.

This iterator does not recurse down the prototype chain.

An iterator visiting all string values in arbitrary order. The iterator element type is &'a Property.

This iterator does not recurse down the prototype chain.