Enum boa::property::PropertyKey [−][src]
This abstracts away the need for IsPropertyKey by transforming the PropertyKey values into an enum with both valid types: String and Symbol
More information:
Variants
String(JsString)Tuple Fields of String
0: JsStringSymbol(JsSymbol)Tuple Fields of Symbol
0: JsSymbolIndex(u32)Tuple Fields of Index
0: u32Trait Implementations
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
Runs Finalize::finalize() on this object and all contained subobjects Read more