[−][src]Struct boa::property::AccessorDescriptor
An accessor descriptor is a property described by a getter-setter pair of functions.
More information:
Implementations
impl AccessorDescriptor[src]
pub fn new(
get: Option<GcObject>,
set: Option<GcObject>,
mut attributes: Attribute
) -> Self[src]
get: Option<GcObject>,
set: Option<GcObject>,
mut attributes: Attribute
) -> Self
Create a new AccessorDescriptor.
If the attributes argument contains a writable flag, it will be removed so only enumerable
and configurable remains.
pub fn getter(&self) -> Option<&GcObject>[src]
Return the getter if it exists.
pub fn setter(&self) -> Option<&GcObject>[src]
Return the setter if it exists.
pub fn set_getter(&mut self, get: Option<GcObject>)[src]
Set the getter of the accessor descriptor.
pub fn set_setter(&mut self, set: Option<GcObject>)[src]
Set the setter of the accessor descriptor.
pub fn attributes(&self) -> Attribute[src]
Return the attributes of the accessor descriptor.
It is guaranteed to not contain a writable flag
pub fn configurable(&self) -> bool[src]
Check whether the descriptor is configurable.
pub fn set_configurable(&mut self, configurable: bool)[src]
Set whether the descriptor is configurable.
pub fn enumerable(&self) -> bool[src]
Check whether the descriptor is enumerable.
pub fn set_enumerable(&mut self, enumerable: bool)[src]
Set whether the descriptor is enumerable.