[−][src]Struct boa::property::DataDescriptor
A data descriptor is a property that has a value, which may or may not be writable.
More information:
Implementations
impl DataDescriptor[src]
pub fn new<V>(value: V, attributes: Attribute) -> Self where
V: Into<Value>, [src]
V: Into<Value>,
Create a new DataDescriptor.
pub fn value(&self) -> Value[src]
Return the value of the data descriptor.
pub fn attributes(&self) -> Attribute[src]
Return the attributes of the descriptor.
pub fn configurable(&self) -> bool[src]
Check whether the descriptor is configurable.
pub fn set_configurable(&mut self, configurable: bool)[src]
Set whether the descriptor is configurable.
pub fn enumerable(&self) -> bool[src]
Check whether the descriptor is enumerable.
pub fn set_enumerable(&mut self, enumerable: bool)[src]
Set whether the descriptor is enumerable.
pub fn writable(&self) -> bool[src]
Check whether the descriptor is writable.
pub fn set_writable(&mut self, writable: bool)[src]
Set whether the descriptor is writable.