Struct boa::property::PropertyDescriptor[][src]

pub struct PropertyDescriptor { /* fields omitted */ }
This represents a JavaScript Property AKA The Property Descriptor.

Property descriptors present in objects come in three main flavors:

  • data descriptors
  • accessor descriptors
  • generic descriptor

A data Property Descriptor is one that includes any fields named either [[Value]] or [[Writable]].

An accessor Property Descriptor is one that includes any fields named either [[Get]] or [[Set]].

A generic Property Descriptor is a Property Descriptor value that is neither a data Property Descriptor nor an accessor Property Descriptor.

More information:

Implementations

An accessor Property Descriptor is one that includes any fields named either [[Get]] or [[Set]].

More information:

A data Property Descriptor is one that includes any fields named either [[Value]] or [[Writable]].

More information:

A generic Property Descriptor is one that is neither a data descriptor nor an accessor descriptor.

More information: