pub struct Break { /* fields omitted */ }
The break statement terminates the current loop, switch, or label statement and transfers
program control to the statement following the terminated statement.
The break statement includes an optional label that allows the program to break out of a
labeled statement. The break statement needs to be nested within the referenced label. The
labeled statement can be any block statement; it does not have to be preceded by a loop
statement.
More information:
Creates a Break AST node.
Gets the label of the break statement, if any.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
Executes the destructor for this type. Read more
Runs this executable in the given context.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
Increments the root-count of all contained Gcs.
Decrements the root-count of all contained Gcs.
Runs Finalize::finalize() on this object and all
contained subobjects Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Convert the Rust type which implements NativeObject to a &dyn Any.
Convert the Rust type which implements NativeObject to a &mut dyn Any.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,