Struct boa::syntax::ast::node::call::Call[][src]

pub struct Call { /* fields omitted */ }
Calling the function actually performs the specified actions with the indicated parameters.

Defining a function does not execute it. Defining it simply names the function and specifies what to do when the function is called. Functions must be in scope when they are called, but the function declaration can be hoisted. The scope of a function is the function in which it is declared (or the entire program, if it is declared at the top level).

More information:

Implementations

Creates a new Call AST node.

Gets the name of the function call.

Retrieves the arguments passed to the function.