Struct boa::syntax::ast::node::conditional::conditional_op::ConditionalOp [−][src]
pub struct ConditionalOp { /* fields omitted */ }Expand description
The conditional (ternary) operator is the only JavaScript operator that takes three
operands.
This operator is the only JavaScript operator that takes three operands: a condition
followed by a question mark (?), then an expression to execute if the condition is
truthy followed by a colon (:), and finally the expression to execute if the condition
is false. This operator is frequently used as a shortcut for the if statement.
More information:
Implementations