Module boa::syntax::ast::node::conditional::if_node[][src]

Structs

The if statement executes a statement if a specified condition is truthy. If the condition is falsy, another statement can be executed.