Struct boa::syntax::ast::node::conditional::if_node::If[][src]

pub struct If { /* fields omitted */ }
The if statement executes a statement if a specified condition is truthy. If the condition is falsy, another statement can be executed.

Multiple if...else statements can be nested to create an else if clause.

Note that there is no elseif (in one word) keyword in JavaScript.

More information:

Implementations

Creates an If AST node.