Struct boa::syntax::ast::node::declaration::arrow_function_decl::ArrowFunctionDecl [−][src]
pub struct ArrowFunctionDecl { /* fields omitted */ }Expand description
An arrow function expression is a syntactically compact alternative to a regular function expression.
Arrow function expressions are ill suited as methods, and they cannot be used as constructors. Arrow functions cannot be used as constructors and will throw an error when used with new.
More information: