Struct boa::syntax::ast::node::declaration::async_function_expr::AsyncFunctionExpr [−][src]
pub struct AsyncFunctionExpr { /* fields omitted */ }Expand description
An async function expression is very similar to an async function declaration except used within a wider expression (for example during an assignment).
More information:
Implementations