Enum boa::syntax::ast::node::declaration::Declaration [−][src]
pub enum Declaration {
Identifier {
ident: Identifier,
init: Option<Node>,
},
Pattern(DeclarationPattern),
}Expand description
Declaration represents either an individual binding or a binding pattern.
For let and const declarations this type represents a LexicalBinding
For var declarations this type represents a VariableDeclaration
More information:
Variants
Fields of Identifier
ident: Identifierinit: Option<Node>Pattern(DeclarationPattern)Tuple Fields of Pattern