Struct boa::syntax::ast::node::declaration::function_decl::FunctionDecl[][src]

pub struct FunctionDecl { /* fields omitted */ }
The function declaration (function statement) defines a function with the specified parameters.

A function created with a function declaration is a Function object and has all the properties, methods and behavior of Function.

A function can also be created using an expression (see function expression).

By default, functions return undefined. To return any other value, the function must have a return statement that specifies the value to return.

More information:

Implementations

Gets the name of the function declaration.

Gets the list of parameters of the function declaration.

Gets the body of the function declaration.