Module boa::syntax::ast::node::declaration::function_expr [−][src]
Structs
The function expression defines a function with the specified parameters.
The function expression defines a function with the specified parameters.