Struct boa::syntax::ast::node::declaration::function_expr::FunctionExpr [−][src]
pub struct FunctionExpr { /* fields omitted */ }Expand description
The function expression defines a function with the specified parameters.
A function created with a function expression is a Function object and has all the
properties, methods and behavior of Function.
A function can also be created using a declaration (see function expression).
By default, functions return undefined. To return any other value, the function must have
a return statement that specifies the value to return.
More information:
Implementations
Gets the list of parameters of the function declaration.
Gets the body of the function declaration.