Enum boa::syntax::ast::node::PropertyName [−][src]
Variants
A Literal property name can be either an identifier, a string or a numeric literal.
More information:
Computed(Node)A Computed property name is an expression that gets evaluated and converted into a property name.
More information:
Tuple Fields of Computed
0: NodeTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
Runs Finalize::finalize() on this object and all contained subobjects Read more