Struct boa::syntax::ast::node::field::get_field::GetField[][src]

pub struct GetField { /* fields omitted */ }
This property accessor provides access to an object’s properties by using the bracket notation.

In the object[property_name] syntax, the property_name is just a string or Symbol. So, it can be any string, including ‘1foo’, ‘!bar!’, or even ’ ’ (a space).

One can think of an object as an associative array (a.k.a. map, dictionary, hash, lookup table). The keys in this array are the names of the object’s properties.

It’s typical when speaking of an object’s properties to make a distinction between properties and methods. However, the property/method distinction is little more than a convention. A method is simply a property that can be called (for example, if it has a reference to a Function instance as its value).

More information:

Implementations

Creates a GetField AST node.