Module boa::syntax::ast::node::iteration::continue_node [−][src]
Structs
The continue statement terminates execution of the statements in the current iteration of
the current or labeled loop, and continues execution of the loop with the next iteration.