Struct boa::syntax::ast::node::iteration::continue_node::Continue[][src]

pub struct Continue { /* fields omitted */ }
The continue statement terminates execution of the statements in the current iteration of the current or labeled loop, and continues execution of the loop with the next iteration.

The continue statement can include an optional label that allows the program to jump to the next iteration of a labeled loop statement instead of the current loop. In this case, the continue statement needs to be nested within this labeled statement.

More information:

Implementations

Creates a Continue AST node.