Struct boa::syntax::ast::node::iteration::do_while_loop::DoWhileLoop [−][src]
pub struct DoWhileLoop { /* fields omitted */ }Expand description
The do...while statement creates a loop that executes a specified statement until the
test condition evaluates to false.
The condition is evaluated after executing the statement, resulting in the specified statement executing at least once.
More information:
Implementations