pub struct Assign { /* private fields */ }Expand description
An assignment operator assigns a value to its left operand based on the value of its right operand.
Assignment operator (=), assigns the value of its right operand to its left operand.
More information:
Implementations