Struct boa::syntax::ast::node::FormalParameter [−][src]
pub struct FormalParameter { /* fields omitted */ }Expand description
“Formal parameter” is a fancy way of saying “function parameter”.
In the declaration of a function, the parameters must be identifiers, not any value like numbers, strings, or objects.
function foo(formalParameter1, formalParameter2) {
}More information:
Implementations