Module boa::syntax::ast::node::switch[][src]

Switch node.

Structs

The switch statement evaluates an expression, matching the expression’s value to a case clause, and executes statements associated with that case, as well as statements in cases that follow the matching case.