pub struct Throw { /* private fields */ }Expand description
The throw statement throws a user-defined exception.
Syntax: throw expression;
Execution of the current function will stop (the statements after throw won’t be executed), and control will be passed to the first catch block in the call stack. If no catch block exists among caller functions, the program will terminate.
More information:
Implementations