Module boa::syntax::ast::node::try_node[][src]

Structs

Catch block.

Finally block.

The try...catch statement marks a block of statements to try and specifies a response should an exception be thrown.