[][src]Struct boa::syntax::ast::pos::Position

pub struct Position {
    pub column_number: u64,
    pub line_number: u64,
}

A position in the Javascript source code Stores both the column number and the line number

Similar Implementations

V8: Location

Fields

column_number: u64line_number: u64

Methods

impl Position[src]

pub fn new(line_number: u64, column_number: u64) -> Position[src]

Create a new position, positions are usually created by Tokens..

See Token for example usage

Arguments

  • line_number - The line number the token starts at
  • column_number - The column number the token starts at