Struct boa::syntax::ast::position::Position [−][src]
pub struct Position { /* fields omitted */ }Expand description
A position in the JavaScript source code.
Stores both the column number and the line number.
Note that spans are of the form [begining, end) i.e. that the begining position is inclusive and the end position is exclusive. See test check_positions from syntax/lexer/tests.rs for an example.
Similar Implementations
Implementations
Gets the line number of the position.
Gets the column number of the position.