Enum boa::value::Numeric [−][src]
Numeric value which can be of two types Number, BigInt.
Variants
Number(f64)Double precision floating point number.
Tuple Fields of Number
0: f64BigInt(JsBigInt)BigInt an integer of arbitrary size.
Tuple Fields of BigInt
0: JsBigIntTrait Implementations
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more