Module boa::builtins::function [−][src]
This module implements the global Function object as well as creates Native Functions.
Objects wrap Functions and expose them via call/construct slots.
The Function` object is used for matching text with a pattern.
More information:
Structs
Wrapper for Box<dyn NativeObject + Clone> that allows passing additional
captures through a Copy closure.
Enums
Boa representation of a Function Object.
Traits
Functions
Arguments.
Creates a new member function of a Object or prototype.
Type Definitions
Type representing a native built-in function a.k.a. function pointer.