Struct boa::builtins::object::Object [−][src]
pub struct Object;Expand description
The global JavaScript object.
Implementations
Object.create( proto, [propertiesObject] )
Creates a new object from the provided prototype.
More information:
Object.getOwnPropertyDescriptor( object, property )
Returns an object describing the configuration of a specific property on a given object.
More information:
Object.getOwnPropertyDescriptors( object )
Returns all own property descriptors of a given object.
More information:
Uses the SameValue algorithm to check equality of objects
Get the prototype of an object.
Set the prototype of an object.
Object.prototype.isPrototypeOf( proto )
Check whether or not an object exists within another object’s prototype chain.
More information:
Define a property in an object
Object.defineProperties( proto, [propertiesObject] )
Creates or update own properties to the object
More information:
Object.prototype.toString()
This method returns a string representing the object.
More information:
Object.prototype.hasOwnPrototype( property )
The method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).
More information:
Object.prototype.propertyIsEnumerable( property )
This method returns a Boolean indicating whether the specified property is enumerable and is the object’s own property.
More information:
Object.assign( target, ...sources )
This method copies all enumerable own properties from one or more source objects to a target object. It returns the target object.
More information:
Object.keys( target )
This method returns an array of a given object’s own enumerable property names, iterated in the same order that a normal loop would.
More information:
Object.entries( target )
This method returns an array of a given object’s own enumerable string-keyed property [key, value] pairs. This is the same as iterating with a for…in loop, except that a for…in loop enumerates properties in the prototype chain as well).
More information: