Trait boa::class::ClassConstructor [−][src]
pub trait ClassConstructor: Class {
fn raw_constructor(
this: &JsValue,
args: &[JsValue],
context: &mut Context
) -> JsResult<JsValue>
where
Self: Sized;
}Expand description
This is a wrapper around Class::constructor that sets the internal data of a class.
This is automatically implemented, when a type implements Class.