Struct boa::environment::function_environment_record::FunctionEnvironmentRecord [−][src]
pub struct FunctionEnvironmentRecord {
pub declarative_record: DeclarativeEnvironmentRecord,
pub this_value: JsValue,
pub this_binding_status: BindingStatus,
pub function: JsObject,
pub home_object: JsValue,
pub new_target: JsValue,
}Expand description
Fields
declarative_record: DeclarativeEnvironmentRecordthis_value: JsValueThis is the this value used for this invocation of the function.
this_binding_status: BindingStatusIf the value is “lexical”, this is an ArrowFunction and does not have a local this value.
function: JsObjectThe function object whose invocation caused this Environment Record to be created.
home_object: JsValueIf the associated function has super property accesses and is not an ArrowFunction,
[[HomeObject]] is the object that the function is bound to as a method.
The default value for [[HomeObject]] is undefined.
new_target: JsValueIf this Environment Record was created by the [[Construct]] internal method,
[[NewTarget]] is the value of the [[Construct]] newTarget parameter.
Otherwise, its value is undefined.
Implementations
pub fn new(
f: JsObject,
this: Option<JsValue>,
outer: Option<Environment>,
binding_status: BindingStatus,
new_target: JsValue,
context: &mut Context
) -> JsResult<FunctionEnvironmentRecord>