macro_rules! empty_trace {
() => { ... };
}Expand description
This rule implements the trace methods with empty implementations.
Use this for marking types as not containing any Trace types.
macro_rules! empty_trace {
() => { ... };
}This rule implements the trace methods with empty implementations.
Use this for marking types as not containing any Trace types.