Module boa::object [−][src]
This module implements the Rust representation of a JavaScript object.
Structs
Builder for creating constructors objects, like Array.
The functions binding.
Builder for creating native function objects
An iterator over the indexed property entries of an Object
An iterator over the index keys (u32) of an Object.
An iterator over the index values (Property) of an Object.
An iterator over the property entries of an Object
Garbage collected Object.
An iterator over the keys (PropertyKey) of an Object.
The internal representation of an JavaScript object.
Defines the kind of an object and its internal methods
Builder for creating objects with properties.
Prevents infinite recursion during Debug::fmt, JSON.stringify, and other conversions.
This uses a thread local, so is not safe to use where the object graph will be traversed by
multiple threads!
An iterator over the String property entries of an Object
An iterator over the string keys (RcString) of an Object.
An iterator over the string values (Property) of an Object.
An iterator over the Symbol property entries of an Object
An iterator over the keys (RcSymbol) of an Object.
An iterator over the Symbol values (Property) of an Object.
An iterator over the values (Property) of an Object.
Enums
Statics
Static prototype, usually set on constructors as a key to point to their respective prototype object.
Traits
This trait allows Rust types to be passed around as objects.