Struct boa::object::ConstructorBuilder[][src]

pub struct ConstructorBuilder<'context> { /* fields omitted */ }
Builder for creating constructors objects, like Array.

Implementations

Create a new ConstructorBuilder.

Add new method to the constructors prototype.

Add new static method to the constructors object itself.

Add new data property to the constructor’s prototype.

Add new static data property to the constructor object itself.

Add new accessor property to the constructor’s prototype.

Add new static accessor property to the constructor object itself.

Add new property to the constructor’s prototype.

Add new static property to the constructor object itself.

Specify how many arguments the constructor function takes.

Default is 0.

Specify the name of the constructor function.

Default is "[object]"

Specify whether the constructor function can be called.

Default is true

Specify whether the constructor function can be called with new keyword.

Default is true

Specify the prototype this constructor object inherits from.

Default is Object.prototype

Return the current context.

Build the constructor function object.