pub struct ObjectData { /* fields omitted */ }
Defines the kind of an object and its internal methods
Create the Array object data and reference its exclusive internal methods
Create the ArrayIterator object data
Create the Map object data
Create the MapIterator object data
Create the RegExp object data
Create the RegExpStringIterator object data
Create the BigInt object data
Create the Boolean object data
Create the ForInIterator object data
Create the Function object data
Create the Set object data
Create the SetIterator object data
Create the String object data and reference its exclusive internal methods
Create the StringIterator object data
Create the Number object data
Create the Symbol object data
Create the Error object data
Create the Ordinary object data
Create the Date object data
Create the Global object data
Create the NativeObject object data
Formats the value using the given formatter. Read more
Executes the destructor for this type. Read more
Increments the root-count of all contained Gcs.
Decrements the root-count of all contained Gcs.
Runs Finalize::finalize() on this object and all
contained subobjects Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Convert the Rust type which implements NativeObject to a &dyn Any.
Convert the Rust type which implements NativeObject to a &mut dyn Any.
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,