Struct boa::object::PropertyMap [−][src]
pub struct PropertyMap { /* fields omitted */ }Implementations
pub fn insert(
&mut self,
key: PropertyKey,
property: PropertyDescriptor
) -> Option<PropertyDescriptor>
An iterator visiting all key-value pairs in arbitrary order. The iterator element type is (PropertyKey, &'a Property).
This iterator does not recurse down the prototype chain.
An iterator visiting all keys in arbitrary order. The iterator element type is PropertyKey.
This iterator does not recurse down the prototype chain.
An iterator visiting all values in arbitrary order. The iterator element type is &'a Property.
This iterator does not recurse down the prototype chain.
pub fn symbol_properties(&self) -> SymbolProperties<'_>ⓘNotable traits for SymbolProperties<'a>impl<'a> Iterator for SymbolProperties<'a> type Item = (&'a JsSymbol, &'a PropertyDescriptor);
pub fn symbol_properties(&self) -> SymbolProperties<'_>ⓘNotable traits for SymbolProperties<'a>impl<'a> Iterator for SymbolProperties<'a> type Item = (&'a JsSymbol, &'a PropertyDescriptor);
impl<'a> Iterator for SymbolProperties<'a> type Item = (&'a JsSymbol, &'a PropertyDescriptor);An iterator visiting all symbol key-value pairs in arbitrary order. The iterator element type is (&'a RcSymbol, &'a Property).
This iterator does not recurse down the prototype chain.
pub fn symbol_property_keys(&self) -> SymbolPropertyKeys<'_>ⓘNotable traits for SymbolPropertyKeys<'a>impl<'a> Iterator for SymbolPropertyKeys<'a> type Item = &'a JsSymbol;
pub fn symbol_property_keys(&self) -> SymbolPropertyKeys<'_>ⓘNotable traits for SymbolPropertyKeys<'a>impl<'a> Iterator for SymbolPropertyKeys<'a> type Item = &'a JsSymbol;
impl<'a> Iterator for SymbolPropertyKeys<'a> type Item = &'a JsSymbol;An iterator visiting all symbol keys in arbitrary order. The iterator element type is &'a RcSymbol.
This iterator does not recurse down the prototype chain.
pub fn symbol_property_values(&self) -> SymbolPropertyValues<'_>ⓘNotable traits for SymbolPropertyValues<'a>impl<'a> Iterator for SymbolPropertyValues<'a> type Item = &'a PropertyDescriptor;
pub fn symbol_property_values(&self) -> SymbolPropertyValues<'_>ⓘNotable traits for SymbolPropertyValues<'a>impl<'a> Iterator for SymbolPropertyValues<'a> type Item = &'a PropertyDescriptor;
impl<'a> Iterator for SymbolPropertyValues<'a> type Item = &'a PropertyDescriptor;An iterator visiting all symbol values in arbitrary order. The iterator element type is &'a Property.
This iterator does not recurse down the prototype chain.
pub fn index_properties(&self) -> IndexProperties<'_>ⓘNotable traits for IndexProperties<'a>impl<'a> Iterator for IndexProperties<'a> type Item = (&'a u32, &'a PropertyDescriptor);
pub fn index_properties(&self) -> IndexProperties<'_>ⓘNotable traits for IndexProperties<'a>impl<'a> Iterator for IndexProperties<'a> type Item = (&'a u32, &'a PropertyDescriptor);
impl<'a> Iterator for IndexProperties<'a> type Item = (&'a u32, &'a PropertyDescriptor);An iterator visiting all indexed key-value pairs in arbitrary order. The iterator element type is (&'a u32, &'a Property).
This iterator does not recurse down the prototype chain.
pub fn index_property_keys(&self) -> IndexPropertyKeys<'_>ⓘNotable traits for IndexPropertyKeys<'a>impl<'a> Iterator for IndexPropertyKeys<'a> type Item = &'a u32;
pub fn index_property_keys(&self) -> IndexPropertyKeys<'_>ⓘNotable traits for IndexPropertyKeys<'a>impl<'a> Iterator for IndexPropertyKeys<'a> type Item = &'a u32;
impl<'a> Iterator for IndexPropertyKeys<'a> type Item = &'a u32;An iterator visiting all index keys in arbitrary order. The iterator element type is &'a u32.
This iterator does not recurse down the prototype chain.
pub fn index_property_values(&self) -> IndexPropertyValues<'_>ⓘNotable traits for IndexPropertyValues<'a>impl<'a> Iterator for IndexPropertyValues<'a> type Item = &'a PropertyDescriptor;
pub fn index_property_values(&self) -> IndexPropertyValues<'_>ⓘNotable traits for IndexPropertyValues<'a>impl<'a> Iterator for IndexPropertyValues<'a> type Item = &'a PropertyDescriptor;
impl<'a> Iterator for IndexPropertyValues<'a> type Item = &'a PropertyDescriptor;An iterator visiting all index values in arbitrary order. The iterator element type is &'a Property.
This iterator does not recurse down the prototype chain.
pub fn string_properties(&self) -> StringProperties<'_>ⓘNotable traits for StringProperties<'a>impl<'a> Iterator for StringProperties<'a> type Item = (&'a JsString, &'a PropertyDescriptor);
pub fn string_properties(&self) -> StringProperties<'_>ⓘNotable traits for StringProperties<'a>impl<'a> Iterator for StringProperties<'a> type Item = (&'a JsString, &'a PropertyDescriptor);
impl<'a> Iterator for StringProperties<'a> type Item = (&'a JsString, &'a PropertyDescriptor);An iterator visiting all string key-value pairs in arbitrary order. The iterator element type is (&'a RcString, &'a Property).
This iterator does not recurse down the prototype chain.
pub fn string_property_keys(&self) -> StringPropertyKeys<'_>ⓘNotable traits for StringPropertyKeys<'a>impl<'a> Iterator for StringPropertyKeys<'a> type Item = &'a JsString;
pub fn string_property_keys(&self) -> StringPropertyKeys<'_>ⓘNotable traits for StringPropertyKeys<'a>impl<'a> Iterator for StringPropertyKeys<'a> type Item = &'a JsString;
impl<'a> Iterator for StringPropertyKeys<'a> type Item = &'a JsString;An iterator visiting all string keys in arbitrary order. The iterator element type is &'a RcString.
This iterator does not recurse down the prototype chain.
pub fn string_property_values(&self) -> StringPropertyValues<'_>ⓘNotable traits for StringPropertyValues<'a>impl<'a> Iterator for StringPropertyValues<'a> type Item = &'a PropertyDescriptor;
pub fn string_property_values(&self) -> StringPropertyValues<'_>ⓘNotable traits for StringPropertyValues<'a>impl<'a> Iterator for StringPropertyValues<'a> type Item = &'a PropertyDescriptor;
impl<'a> Iterator for StringPropertyValues<'a> type Item = &'a PropertyDescriptor;An iterator visiting all string values in arbitrary order. The iterator element type is &'a Property.
This iterator does not recurse down the prototype chain.