Enum boa::syntax::ast::keyword::Keyword[][src]

pub enum Keyword {
Show 41 variants Await, Async, Break, Case, Catch, Class, Continue, Const, Debugger, Default, Delete, Do, Else, Enum, Export, Extends, False, Finally, For, Function, If, In, InstanceOf, Import, Let, New, Null, Of, Return, Super, Switch, This, Throw, True, Try, TypeOf, Var, Void, While, With, Yield,
}
Keywords are tokens that have special meaning in JavaScript.

In JavaScript you cannot use these reserved words as variables, labels, or function names.

More information:

Variants

Await

The await keyword.

More information:

Async

The async keyword.

More information:

Break
Case
Catch

The catch keyword.

More information:

Class

The class keyword.

More information:

Continue

The continue keyword.

More information:

Const
Debugger

The debugger keyword.

More information:

Default
Delete
Do

The do keyword.

More information:

Else

The else keyword.

More information:

Enum

The enum keyword.

Future reserved keyword.

Export

The export keyword.

More information:

Extends

The extends keyword.

More information:

False

The false keyword.

More information:

Finally

The finally keyword.

More information:

For
Function

The function keyword.

More information:

If
In

The in keyword.

More information:

InstanceOf

The instanceof keyword.

More information:

Import

The import keyword.

More information:

Let
New
Null

The null keyword.

More information:

Of

The of keyword.

More information:

Return
Super

The super keyword

More information:

Switch
This
Throw
True

The true keyword

More information:

Try
TypeOf
Var
Void
While
With

The with keyword.

More information:

Yield

The ‘yield’ keyword.

More information:

Implementations

Gets the keyword as a binary operation, if this keyword is the in keyword.

Gets the keyword as a string.