Enum boa::syntax::ast::keyword::Keyword [−][src]
pub enum Keyword {
Show 41 variants
Await,
Async,
Break,
Case,
Catch,
Class,
Continue,
Const,
Debugger,
Default,
Delete,
Do,
Else,
Enum,
Export,
Extends,
False,
Finally,
For,
Function,
If,
In,
InstanceOf,
Import,
Let,
New,
Null,
Of,
Return,
Super,
Switch,
This,
Throw,
True,
Try,
TypeOf,
Var,
Void,
While,
With,
Yield,
}Expand description
Keywords are tokens that have special meaning in JavaScript.
In JavaScript you cannot use these reserved words as variables, labels, or function names.
More information:
Variants
The break keyword.
More information:
The case keyword.
More information:
The continue keyword.
More information:
The const keyword.
More information:
The default keyword.
More information:
The delete keyword.
More information:
The enum keyword.
Future reserved keyword.
The finally keyword.
More information:
The for keyword.
More information:
The function keyword.
More information:
The return keyword
More information:
The switch keyword.
More information:
The throw keyword.
More information:
The typeof keyword.
More information:
The void keyword.
More information:
The while keyword.
More information:
Implementations