Module boa::syntax::ast::node::break_node [−][src]
Structs
The break statement terminates the current loop, switch, or label statement and transfers
program control to the statement following the terminated statement.