pub struct Call { /* fields omitted */ }
Calling the function actually performs the specified actions with the indicated parameters.
Defining a function does not execute it. Defining it simply names the function and
specifies what to do when the function is called. Functions must be in scope when they are
called, but the function declaration can be hoisted. The scope of a function is the
function in which it is declared (or the entire program, if it is declared at the top
level).
More information:
Creates a new Call AST node.
Gets the name of the function call.
Retrieves the arguments passed to the function.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
Executes the destructor for this type. Read more
Runs this executable in the given context.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
Increments the root-count of all contained Gcs.
Decrements the root-count of all contained Gcs.
Runs Finalize::finalize() on this object and all
contained subobjects Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Convert the Rust type which implements NativeObject to a &dyn Any.
Convert the Rust type which implements NativeObject to a &mut dyn Any.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,