Enum boa::syntax::ast::node::declaration::BindingPatternTypeArray [−][src]
pub enum BindingPatternTypeArray {
Empty,
Elision,
SingleName {
ident: Box<str>,
default_init: Option<Node>,
},
BindingPattern {
pattern: DeclarationPattern,
},
SingleNameRest {
ident: Box<str>,
},
BindingPatternRest {
pattern: DeclarationPattern,
},
}Expand description
BindingPatternTypeArray represents the different types of bindings that an array binding pattern may contain.
More information:
Variants
Empty represents an empty array binding pattern e.g. [ ].
This may occur because the Elision and BindingRestElement in the first type of
array binding pattern are both optional.
More information:
Elision represents the elision of an item in the array binding pattern.
An Elision may occur at multiple points in the pattern and may be multiple elisions.
This variant strictly represents one elision. If there are multiple, this should be used multiple times.
More information:
SingleName represents a SingleNameBinding with an identifier and an optional default initializer.
More information:
BindingPattern represents a BindingPattern in a BindingElement of an array binding pattern.
The pattern and the optional default initializer are both stored in the DeclarationPattern.
More information:
Fields of BindingPattern
pattern: DeclarationPatternSingleNameRest represents a BindingIdentifier in a BindingRestElement of an array binding pattern.
More information:
SingleNameRest represents a BindingPattern in a BindingRestElement of an array binding pattern.
More information:
Fields of BindingPatternRest
pattern: DeclarationPatternTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
Runs Finalize::finalize() on this object and all contained subobjects Read more