Enum boa::syntax::ast::node::declaration::BindingPatternTypeObject [−][src]
pub enum BindingPatternTypeObject {
Empty,
SingleName {
ident: Box<str>,
property_name: Box<str>,
default_init: Option<Node>,
},
RestProperty {
ident: Box<str>,
excluded_keys: Vec<Box<str>>,
},
BindingPattern {
ident: Box<str>,
pattern: DeclarationPattern,
default_init: Option<Node>,
},
}Expand description
BindingPatternTypeObject represents the different types of bindings that an object binding pattern may contain.
More information:
Variants
Empty represents an empty object binding pattern e.g. { }.
SingleName represents one of the following properties:
SingleNameBindingwith an identifier and an optional default initializer.BindingPropertywith an property name and aSingleNameBindingas theBindingElement.
More information:
RestProperty represents a BindingRestProperty with an identifier.
It also includes a list of the property keys that should be excluded from the rest, because they where already assigned.
More information:
BindingPattern represents a BindingProperty with a BindingPattern as the BindingElement.
Additionally to the identifier of the new property and the nested binding pattern, this may also include an optional default initializer.
More information:
Fields of BindingPattern