Enum boa::syntax::ast::node::Node[][src]

pub enum Node {
Show 39 variants ArrayDecl(ArrayDecl), ArrowFunctionDecl(ArrowFunctionDecl), Assign(Assign), AsyncFunctionDecl(AsyncFunctionDecl), AsyncFunctionExpr(AsyncFunctionExpr), AwaitExpr(AwaitExpr), BinOp(BinOp), Block(Block), Break(Break), Call(Call), ConditionalOp(ConditionalOp), Const(Const), ConstDeclList(DeclarationList), Continue(Continue), DoWhileLoop(DoWhileLoop), FunctionDecl(FunctionDecl), FunctionExpr(FunctionExpr), GetConstField(GetConstField), GetField(GetField), ForLoop(ForLoop), ForInLoop(ForInLoop), ForOfLoop(ForOfLoop), If(If), LetDeclList(DeclarationList), Identifier(Identifier), New(New), Object(Object), Return(Return), Switch(Switch), Spread(Spread), TaggedTemplate(TaggedTemplate), TemplateLit(TemplateLit), Throw(Throw), Try(Try), This, UnaryOp(UnaryOp), VarDeclList(DeclarationList), WhileLoop(WhileLoop), Empty,
}

Variants

ArrayDecl(ArrayDecl)

Array declaration node. More information.

Tuple Fields of ArrayDecl

0: ArrayDecl
ArrowFunctionDecl(ArrowFunctionDecl)

An arrow function expression node. More information.

Tuple Fields of ArrowFunctionDecl

0: ArrowFunctionDecl
Assign(Assign)

An assignment operator node. More information.

Tuple Fields of Assign

0: Assign
AsyncFunctionDecl(AsyncFunctionDecl)

An async function declaration node. More information.

Tuple Fields of AsyncFunctionDecl

0: AsyncFunctionDecl
AsyncFunctionExpr(AsyncFunctionExpr)

An async function expression node. More information.

Tuple Fields of AsyncFunctionExpr

0: AsyncFunctionExpr
AwaitExpr(AwaitExpr)

An await expression node. More information.

Tuple Fields of AwaitExpr

0: AwaitExpr
BinOp(BinOp)

A binary operator node. More information.

Tuple Fields of BinOp

0: BinOp
Block(Block)

A Block node. More information.

Tuple Fields of Block

0: Block
Break(Break)

A break node. More information.

Tuple Fields of Break

0: Break
Call(Call)

A function call. More information.

Tuple Fields of Call

0: Call
ConditionalOp(ConditionalOp)

A javascript conditional operand ( x ? y : z ). More information.

Tuple Fields of ConditionalOp

0: ConditionalOp
Const(Const)

Literals represent values in JavaScript.

These are fixed values not variables that you literally provide in your script.

More information:

Tuple Fields of Const

0: Const
ConstDeclList(DeclarationList)

A constant declaration list. More information.

Tuple Fields of ConstDeclList

0: DeclarationList
Continue(Continue)

A continue statement. More information.

Tuple Fields of Continue

0: Continue
DoWhileLoop(DoWhileLoop)

A do … while statement. More information.

Tuple Fields of DoWhileLoop

0: DoWhileLoop
FunctionDecl(FunctionDecl)

A function declaration node. More information.

Tuple Fields of FunctionDecl

0: FunctionDecl
FunctionExpr(FunctionExpr)

A function expression node. More information.

Tuple Fields of FunctionExpr

0: FunctionExpr
GetConstField(GetConstField)

Provides access to an object types’ constant properties. More information.

Tuple Fields of GetConstField

0: GetConstField
GetField(GetField)

Provides access to object fields. More information.

Tuple Fields of GetField

0: GetField
ForLoop(ForLoop)

A for statement. More information.

Tuple Fields of ForLoop

0: ForLoop
ForInLoop(ForInLoop)

A for...of or for..in statement. More information.

Tuple Fields of ForInLoop

0: ForInLoop
ForOfLoop(ForOfLoop)

A for...of statement. More information.

Tuple Fields of ForOfLoop

0: ForOfLoop
If(If)

An ‘if’ statement. More information.

Tuple Fields of If

0: If
LetDeclList(DeclarationList)

A let declaration list. More information.

Tuple Fields of LetDeclList

0: DeclarationList
Identifier(Identifier)

A local identifier node. More information.

Tuple Fields of Identifier

0: Identifier
New(New)

A new expression. More information.

Tuple Fields of New

0: New
Object(Object)

An object. More information.

Tuple Fields of Object

0: Object
Return(Return)

A return statement. More information.

Tuple Fields of Return

0: Return
Switch(Switch)

A switch {case} statement. More information.

Tuple Fields of Switch

0: Switch
Spread(Spread)

A spread (…x) statement. More information.

Tuple Fields of Spread

0: Spread
TaggedTemplate(TaggedTemplate)

A tagged template. More information.

Tuple Fields of TaggedTemplate

0: TaggedTemplate
TemplateLit(TemplateLit)

A template literal. More information.

Tuple Fields of TemplateLit

0: TemplateLit
Throw(Throw)

A throw statement. More information.

Tuple Fields of Throw

0: Throw
Try(Try)

A try...catch node. More information.

Tuple Fields of Try

0: Try
This

The JavaScript this keyword refers to the object it belongs to.

A property of an execution context (global, function or eval) that, in non–strict mode, is always a reference to an object and in strict mode can be any value.

More information:

UnaryOp(UnaryOp)

Unary operation node. More information

Tuple Fields of UnaryOp

0: UnaryOp
VarDeclList(DeclarationList)

Array declaration node. More information.

Tuple Fields of VarDeclList

0: DeclarationList
WhileLoop(WhileLoop)

A ‘while {…}’ node. More information.

Tuple Fields of WhileLoop

0: WhileLoop
Empty

A empty node.

Empty statement do nothing, just return undefined.

More information:

Implementations

Creates a This AST node.