Enum boa::syntax::ast::node::Node [−][src]
pub enum Node {
Show 39 variants
ArrayDecl(ArrayDecl),
ArrowFunctionDecl(ArrowFunctionDecl),
Assign(Assign),
AsyncFunctionDecl(AsyncFunctionDecl),
AsyncFunctionExpr(AsyncFunctionExpr),
AwaitExpr(AwaitExpr),
BinOp(BinOp),
Block(Block),
Break(Break),
Call(Call),
ConditionalOp(ConditionalOp),
Const(Const),
ConstDeclList(DeclarationList),
Continue(Continue),
DoWhileLoop(DoWhileLoop),
FunctionDecl(FunctionDecl),
FunctionExpr(FunctionExpr),
GetConstField(GetConstField),
GetField(GetField),
ForLoop(ForLoop),
ForInLoop(ForInLoop),
ForOfLoop(ForOfLoop),
If(If),
LetDeclList(DeclarationList),
Identifier(Identifier),
New(New),
Object(Object),
Return(Return),
Switch(Switch),
Spread(Spread),
TaggedTemplate(TaggedTemplate),
TemplateLit(TemplateLit),
Throw(Throw),
Try(Try),
This,
UnaryOp(UnaryOp),
VarDeclList(DeclarationList),
WhileLoop(WhileLoop),
Empty,
}Variants
ArrayDecl(ArrayDecl)Array declaration node. More information.
Tuple Fields of ArrayDecl
0: ArrayDeclArrowFunctionDecl(ArrowFunctionDecl)An arrow function expression node. More information.
Tuple Fields of ArrowFunctionDecl
Assign(Assign)An assignment operator node. More information.
Tuple Fields of Assign
0: AssignAsyncFunctionDecl(AsyncFunctionDecl)An async function declaration node. More information.
Tuple Fields of AsyncFunctionDecl
AsyncFunctionExpr(AsyncFunctionExpr)An async function expression node. More information.
Tuple Fields of AsyncFunctionExpr
AwaitExpr(AwaitExpr)An await expression node. More information.
Tuple Fields of AwaitExpr
0: AwaitExprBinOp(BinOp)A binary operator node. More information.
Tuple Fields of BinOp
0: BinOpBlock(Block)A Block node. More information.
Tuple Fields of Block
0: BlockBreak(Break)A break node. More information.
Tuple Fields of Break
0: BreakCall(Call)A function call. More information.
Tuple Fields of Call
0: CallConditionalOp(ConditionalOp)A javascript conditional operand ( x ? y : z ). More information.
Tuple Fields of ConditionalOp
Const(Const)Literals represent values in JavaScript.
These are fixed values not variables that you literally provide in your script.
More information:
Tuple Fields of Const
0: ConstConstDeclList(DeclarationList)A constant declaration list. More information.
Tuple Fields of ConstDeclList
Continue(Continue)A continue statement. More information.
Tuple Fields of Continue
0: ContinueDoWhileLoop(DoWhileLoop)A do … while statement. More information.
Tuple Fields of DoWhileLoop
0: DoWhileLoopFunctionDecl(FunctionDecl)A function declaration node. More information.
Tuple Fields of FunctionDecl
0: FunctionDeclFunctionExpr(FunctionExpr)A function expression node. More information.
Tuple Fields of FunctionExpr
0: FunctionExprGetConstField(GetConstField)Provides access to an object types’ constant properties. More information.
Tuple Fields of GetConstField
GetField(GetField)Provides access to object fields. More information.
Tuple Fields of GetField
0: GetFieldForLoop(ForLoop)A for statement. More information.
Tuple Fields of ForLoop
0: ForLoopForInLoop(ForInLoop)A for...of or for..in statement. More information.
Tuple Fields of ForInLoop
0: ForInLoopForOfLoop(ForOfLoop)A for...of statement. More information.
Tuple Fields of ForOfLoop
0: ForOfLoopIf(If)An ‘if’ statement. More information.
Tuple Fields of If
0: IfLetDeclList(DeclarationList)A let declaration list. More information.
Tuple Fields of LetDeclList
Identifier(Identifier)A local identifier node. More information.
Tuple Fields of Identifier
0: IdentifierNew(New)A new expression. More information.
Tuple Fields of New
0: NewObject(Object)An object. More information.
Tuple Fields of Object
0: ObjectReturn(Return)A return statement. More information.
Tuple Fields of Return
0: ReturnSwitch(Switch)A switch {case} statement. More information.
Tuple Fields of Switch
0: SwitchSpread(Spread)A spread (…x) statement. More information.
Tuple Fields of Spread
0: SpreadTaggedTemplate(TaggedTemplate)A tagged template. More information.
Tuple Fields of TaggedTemplate
TemplateLit(TemplateLit)A template literal. More information.
Tuple Fields of TemplateLit
0: TemplateLitThrow(Throw)A throw statement. More information.
Tuple Fields of Throw
0: ThrowTry(Try)A try...catch node. More information.
Tuple Fields of Try
0: TryThe JavaScript this keyword refers to the object it belongs to.
A property of an execution context (global, function or eval) that, in non–strict mode, is always a reference to an object and in strict mode can be any value.
More information:
UnaryOp(UnaryOp)Unary operation node. More information
Tuple Fields of UnaryOp
0: UnaryOpVarDeclList(DeclarationList)Array declaration node. More information.
Tuple Fields of VarDeclList
WhileLoop(WhileLoop)A ‘while {…}’ node. More information.
Tuple Fields of WhileLoop
0: WhileLoopA empty node.
Empty statement do nothing, just return undefined.
More information:
Implementations