Module boa::syntax::ast::node::object [−][src]
Object node.
Structs
Objects in JavaScript may be defined as an unordered collection of related data, of primitive or reference types, in the form of “key: value” pairs.