[−][src]Enum boa::syntax::ast::op::CompOp
A comparitive operation between 2 values
Variants
Equala == b - Equality
NotEquala != b - Unequality
StrictEquala === b - Strict equality
StrictNotEquala !== b - Strict unequality
GreaterThana > b - If a is greater than b
GreaterThanOrEquala >= b - If a is greater than or equal to b
LessThana < b - If a is less than b
LessThanOrEquala <= b - If a is less than or equal to b