pub enum CompOp {
Equal,
NotEqual,
StrictEqual,
StrictNotEqual,
GreaterThan,
GreaterThanOrEqual,
LessThan,
LessThanOrEqual,
}Expand description
A comparitive operation between 2 values
Variants
Equal
a == b - Equality
NotEqual
a != b - Unequality
StrictEqual
a === b - Strict equality
StrictNotEqual
a !== b - Strict unequality
GreaterThan
a > b - If a is greater than b
GreaterThanOrEqual
a >= b - If a is greater than or equal to b
LessThan
a < b - If a is less than b
LessThanOrEqual
a <= b - If a is less than or equal to b