Enum boa::syntax::lexer::token::TokenKind[][src]

pub enum TokenKind {
Show 13 variants BooleanLiteral(bool), EOF, Identifier(Box<str>), Keyword(Keyword), NullLiteral, NumericLiteral(Numeric), Punctuator(Punctuator), StringLiteral(Box<str>), TemplateNoSubstitution(TemplateString), TemplateMiddle(TemplateString), RegularExpressionLiteral(Box<str>, RegExpFlags), LineTerminator, Comment,
}
Represents the type of Token and the data it has inside.

Variants

BooleanLiteral(bool)

A boolean literal, which is either true or false.

Tuple Fields of BooleanLiteral

0: bool
EOF

The end of the file.

Identifier(Box<str>)

An identifier.

Tuple Fields of Identifier

0: Box<str>
Keyword(Keyword)

A keyword.

see: Keyword

Tuple Fields of Keyword

0: Keyword
NullLiteral

A null literal.

NumericLiteral(Numeric)

A numeric literal.

Tuple Fields of NumericLiteral

0: Numeric
Punctuator(Punctuator)

A piece of punctuation

see: Punctuator

Tuple Fields of Punctuator

0: Punctuator
StringLiteral(Box<str>)

A string literal.

Tuple Fields of StringLiteral

0: Box<str>
TemplateNoSubstitution(TemplateString)

A part of a template literal without substitution.

Tuple Fields of TemplateNoSubstitution

0: TemplateString
TemplateMiddle(TemplateString)

The part of a template literal between substitutions

Tuple Fields of TemplateMiddle

0: TemplateString
RegularExpressionLiteral(Box<str>, RegExpFlags)

A regular expression, consisting of body and flags.

Tuple Fields of RegularExpressionLiteral

0: Box<str>1: RegExpFlags
LineTerminator

Indicates the end of a line (\n).

Comment

Indicates a comment, the content isn’t stored.

Implementations

Creates a BooleanLiteral token kind.

Creates an EOF token kind.

Creates an Identifier token type.

Creates a Keyword token kind.

Creates a NumericLiteral token kind.

Creates a Punctuator token type.

Creates a StringLiteral token type.

Creates a RegularExpressionLiteral token kind.

Creates a LineTerminator token kind.

Creates a ‘Comment’ token kind.