Enum boa::syntax::parser::error::ParseError [−][src]
pub enum ParseError {
Expected {
expected: Box<[TokenKind]>,
found: Token,
context: &'static str,
},
Unexpected {
found: Token,
message: Option<&'static str>,
},
AbruptEnd,
Lex {
err: LexError,
},
General {
message: &'static str,
position: Position,
},
Unimplemented {
message: &'static str,
position: Position,
},
}Expand description
ParseError is an enum which represents errors encounted during parsing an expression
Variants
When it expected a certain kind of token, but got another as part of something
When a token is unexpected
When there is an abrupt end to the parsing
A lexing error.
Fields of Lex
err: LexErrorCatch all General Error
Unimplemented syntax error